@@ -157,6 +157,23 @@ class Box(object):
         """
         return self.unpack(buf, save=False)
 
+    def map(self, **kwargs):
+        """
+        获取对应的response
+        :param kwargs:
+        :return:
+        """
+        box = self.__class__()
+
+        for attr_name in ('cmd', 'sn'):
+            if hasattr(self, attr_name):
+                setattr(box, attr_name, getattr(self, attr_name))
+
+        for k, v in kwargs.items():
+            setattr(box, k, v)
+
+        return box
+
     def get_json(self):
         """
         解析为json格式
